@@ -209,6 +209,11 @@ impl Launcher {
             cmd.add_arg("--init");
         }
 
+        // --interactive
+        if opt.interactive {
+            cmd.add_arg("--interactive");
+        }
+
         // --name
         if let Some(name) = &opt.name {
             cmd.add_arg_pair("--name", name);
@@ -234,6 +239,11 @@ impl Launcher {
             cmd.add_arg("--rm");
         }
 
+        // --tty
+        if opt.tty {
+            cmd.add_arg("--tty");
+        }
+
         // --user
         if let Some(user) = &opt.user {
             cmd.add_arg_pair("--user", user.arg());
@@ -522,6 +532,9 @@ pub struct RunOpt {
     /// reaps processes.
     pub init: bool,
 
+    /// Keep stdin open even if not attached.
+    pub interactive: bool,
+
     /// Optional name to give the container.
     pub name: Option<String>,
 
@@ -541,6 +554,9 @@ pub struct RunOpt {
     /// exits. Defaults to `false`.
     pub remove: bool,
 
+    /// Allocate a psuedo-TTY.
+    pub tty: bool,
+
     /// Volumes to mount in the container.
     pub volumes: Vec<Volume>,
 
